@@ -1,4 +1,4 @@
-from .protocols import *
+from .schema import *
 from .feedforward import *
 from .token_mixers import *
 from .poolers import *
